@@ -166,6 +166,8 @@ class MobioMediaSDK(object):
         else:
             with open(dist_file, "wb") as f:
                 f.write(file_byte)
+        from .utils import file_capacity
+        capacity = file_capacity(dist_file)
         url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, filename)
         if short_link:
             url = os.path.join(host_by_merchant_id, self.folder_static, filename)
@@ -190,7 +192,8 @@ class MobioMediaSDK(object):
             FieldConstantResponse.URL: url,
             FieldConstantResponse.LOCAL_PATH: dist_file,
             FieldConstantResponse.FILENAME: filename,
-            FieldConstantResponse.FORMAT: mimetype_str
+            FieldConstantResponse.FORMAT: mimetype_str,
+            FieldConstantResponse.CAPACITY: capacity
         }
 
     def upload_with_kafka(
@@ -258,6 +261,8 @@ class MobioMediaSDK(object):
         else:
             with open(tmp_file, "wb") as f:
                 f.write(file_byte)
+        from .utils import file_capacity
+        capacity = file_capacity(tmp_file)
         logger.debug("upload_with_kafka()::move file:: %s" % (time.time() - time_start))
         dist_file, filename = self.create_dir_save_file(
             folder=STATIC_DATA_DIR,
@@ -292,6 +297,7 @@ class MobioMediaSDK(object):
             FieldConstantResponse.LOCAL_PATH: dist_file,
             FieldConstantResponse.FILENAME: filename,
             FieldConstantResponse.FORMAT: mimetype_str,
+            FieldConstantResponse.CAPACITY: capacity,
         }
 
     def create_public_url_without_file(
